# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from cogneed_protos.cogneed_ks.services import forward_audio_pb2 as cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2


class ForwardAudioServiceStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.collect = channel.stream_stream(
        '/ai.cogneed.cloud.speech.v1.ForwardAudioService/collect',
        request_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.ForwardAudioRequest.SerializeToString,
        response_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.ForwardAudioResponse.FromString,
        )


class ForwardAudioServiceServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def collect(self, request_iterator, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_ForwardAudioServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'collect': grpc.stream_stream_rpc_method_handler(
          servicer.collect,
          request_deserializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.ForwardAudioRequest.FromString,
          response_serializer=cogneed__protos_dot_cogneed__ks_dot_services_dot_forward__audio__pb2.ForwardAudioResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'ai.cogneed.cloud.speech.v1.ForwardAudioService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
